import Vue from 'vue'
import Vuex from 'vuex'
import { getUser, logout, getPermissions } from '@/api/account'

Vue.use(Vuex)

const store = new Vuex.Store({
  state: {
    user: {},
    permissions: []
  },
  mutations: {
    setUser(state, user) {
      state.user = user.data
    },
    setPermissions(state, permissions) {
      state.permissions = permissions
    }
  },
  actions: {
    getUser({ commit }) {
      getUser().then(response => {
        commit('setUser', response)
      })
    },
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        return response
      })
    },
    // 检测登录状态
    async checkLogin({ commit, dispatch }) {
      const isLogin = await getUser()
        .then(response => {
          commit('setUser', response)
          return true
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      await dispatch('getPermissions')
      return isLogin
    },
    // 获取所有权限列表
    async getPermissions({ commit }) {
      await getPermissions({ type: 1 }).then(res => {
        if (res.data && res.data.items) {
          commit('setPermissions', res.data.items)
        }
      })
    }
  }
})

export default store
